import numpy as np
import bayesian_track_analysis.process as process

# FUNCTION censortracksbymaxdisplacement(tracks, maxdisp)
# Discards any tracks with one or more framewise displacements above the specified value
# INPUTS:
# tracks - Cartesian representation of tracks, as loaded directly in using io
# maxdisp - the upper threshold for displacements, above which tracks are discarded
# OUTPUTS:
# tracksout - new list of tracks, after censoring

def censortracksbymaxdisplacement(tracks, maxdisp):
        
#    tracksout = []
#    for i in range(len(tracks)):
#        
#        thistrack = tracks_rt[i]
#        if not np.any(thistrack[0]>maxdisp):
#            tracksout.append(tracks[i])

    censoridx = censorbymaxdisplacement(tracks, maxdisp)
    tracksout = [tracks[i] for i in np.where(censoridx)[0]]
    
    return tracksout

# END FUNCTION

# FUNCTION censorbymaxdisplacement(tracks, maxdisp)
# Discards any tracks with one or more framewise displacements above the specified value
# INPUTS:
# tracks - Cartesian representation of tracks, as loaded directly in using io
# maxdisp - the upper threshold for displacements, above which tracks are discarded
# OUTPUTS:
# censoridx - list of Bool, true means keep track, false means discard it

def censorbymaxdisplacement(tracks, maxdisp):
    
    # convert to r, theta form
    tracks_rt = process.trackcarttopolar(tracks)
    
    censoridx = [True]*len(tracks)
    
    for i in range(len(tracks)):
        
        thistrack = tracks_rt[i]
        if np.any(thistrack[0]>maxdisp):
            censoridx[i] = False
        
    return censoridx

# END FUNCTION

# FUNCTION censorbyminbounddiameter(tracks, mbd)
# Discards any tracks with MBD below the specified value
# INPUTS:
# tracks - Cartesian representation of tracks, as loaded directly in using io
# mbd - the lower threshold for MBD, below which tracks are discarded
# OUTPUTS:
# censoridx - list of Bool, true means keep track, false means discard it

def censorbyminbounddiameter(tracks, mbd):
        
    diams = process.computeminbounddiameter(tracks)
    
    censoridx = [x>mbd for x in diams]
        
    return censoridx

# END FUNCTION

# FUNCTION censortracksbyminbounddiameter(tracks, mbd)
# as for censorbyminbounddiameter, but returns a new tracks list

def censortracksbyminbounddiameter(tracks, mbd):
    
    censoridx = censortracksbyminbounddiameter(tracks, mbd)
    tracksout = [tracks[i] for i in np.where(censoridx)[0]]    
    return tracksout

# END FUNCTION